@@ -8,15 +8,14 @@
 #' \code{\link{slurm_apply}} or \code{\link{slurm_call}}, but it may be necessary 
 #' to manually recreate one if the job was submitted in a different R session.
 #' 
-#' @param jobname The name of the SLURM job. The rslurm-generated scripts and 
+#' @param jobname The name of the Slurm job. The rslurm-generated scripts and 
 #' output files associated with a job should be found in the 
 #' \emph{_rslurm_[jobname]} folder.
 #' @param nodes The number of cluster nodes used by that job.
-#' @param jobid The job ID assigned to a job on submission.
 #' @return A \code{slurm_job} object.
 #' @export
-slurm_job <- function(jobname, nodes, jobid) {
-    slr_job <- list(jobname = jobname, nodes = nodes, jobid = jobid)
+slurm_job <- function(jobname, nodes) {
+    slr_job <- list(jobname = jobname, nodes = nodes)
     class(slr_job) <- "slurm_job"
     slr_job
 }
